@@ -13,8 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import absolute_import
-
 import logging
 import traceback
 from optlang._version import get_versions
@@ -72,7 +70,7 @@ if available_solvers['SCIPY']:
 
 # Go through and find the best solver that loaded. Load that one as the default
 for engine_str in ['cplex_interface', 'gurobi_interface', 'glpk_interface',
-                   'scipy_interface', 'coinor_cbc_interface']:
+                   'hybrid_interface', 'scipy_interface', 'coinor_cbc_interface']:
     # Must check globals since not all interface variables will be defined
     if engine_str in globals():
         engine = globals()[engine_str]
