@@ -1577,6 +1577,8 @@ class Model(object):
         keys = [constraint.name for constraint in constraints]
         if len(constraints) > 350:  # Need to figure out a good threshold here
             self._constraints = self._constraints.fromkeys(set(self._constraints.keys()).difference(set(keys)))
+            for co in constraints:
+                co.problem = None
         else:
             for constraint in constraints:
                 try:
