@@ -823,7 +823,11 @@ class AbstractModelTestCase(unittest.TestCase, metaclass=abc.ABCMeta):
         objective = self.model.objective
         self.model.objective = self.interface.Objective(objective.expression + 3)
         self.model.update()
-        self.assertEqual((self.model.objective.expression - (objective.expression + 3.)).expand(), 0.)
+        self.assertEqual(
+            float((self.model.objective.expression -
+                  (objective.expression + 3.)).expand().evalf()),
+            0.
+        )
 
     def test_is_integer(self):
         model = self.model
