@@ -106,7 +106,7 @@ def list_available_solvers():
         A dict like {'GLPK': True, 'GUROBI': False, ...}
     """
     solvers = dict(GUROBI=False, GLPK=False, MOSEK=False, CPLEX=False,
-                   COINOR_CBC=False, SCIPY=False, OSQP=False)
+                   COINOR_CBC=False, SCIPY=False, OSQP=False, HIGHS=False)
     try:
         import gurobipy
 
@@ -152,6 +152,14 @@ def list_available_solvers():
         pass
     if not solvers['OSQP']:
         log.debug('OSQP python bindings not available.')
+    try:
+        import highspy
+        solvers['HIGHS'] = True
+        log.debug('HIGHS python bindings found at %s' % os.path.dirname(highspy.__file__))
+    except Exception:
+        pass
+    if not solvers['OSQP'] and not solvers['HIGHS']:
+        log.debug('HIGHS python bindings not available.')
     try:
         import mip
 
